@@ -16,41 +16,6 @@
 
 #' Creates a flextable object from a dataframe
 #'
-#' @param x A dataframe.
-#' @param delim Delimiter.
-#' @param style  Named list that specifies how to style the different parts of
-#' the gt or flextable table generated. Accepted style entries are: title,
-#' subtitle, header, header_name, header_level, column_name, group_label, and
-#' body.
-#' Alternatively, use "default" to get visOmopResults style, or NULL for
-#' gt/flextable style.
-#' Keep in mind that styling code is different for gt and flextable. To see
-#' the "deafult" gt style code use `tableStyle()`.
-#' @param na How to display missing values.
-#' @param title Title of the table, or NULL for no title.
-#' @param subtitle Subtitle of the table, or NULL for no subtitle.
-#' @param caption Caption for the table, or NULL for no caption. Text in
-#' markdown formatting style (e.g. `*Your caption here*` for caption in
-#' italics).
-#' @param groupColumn Specifies the columns to use for group labels.
-#' By default, the new group name will be a combination of the column names,
-#' joined by "_". To assign a custom group name, provide a named list such as:
-#' list(`newGroupName` = c("variable_name", "variable_level"))
-#' @param groupAsColumn Whether to display the group labels as a column
-#' (TRUE) or rows (FALSE).
-#' @param groupOrder Order in which to display group labels.
-#' @param merge Names of the columns to merge vertically
-#' when consecutive row cells have identical values. Alternatively, use
-#' "all_columns" to apply this merging to all columns, or use NULL to indicate
-#' no merging.
-#'
-#' @return A flextable object.
-#'
-#' @description
-#' Creates a flextable object from a dataframe using a delimiter to span
-#' the header, and allows to easily customise table style.
-#'
-#' @return A flextable object.
 #' @noRd
 #'
 fxTableInternal <- function(x,
@@ -69,6 +34,8 @@ fxTableInternal <- function(x,
   rlang::check_installed("flextable")
   rlang::check_installed("officer")
 
+  flextable::set_flextable_defaults(table.layout = "autofit")
+
   # na
   if (!is.null(na)) {
     x <- x |>
@@ -265,7 +232,7 @@ fxTableInternal <- function(x,
   flex_x <- flex_x |>
     flextable::border_outer(
       part = "all",
-      border = officer::fp_border(color = flex_x$body$styles$cells$border.color.top$data[1,1], width = 2)
+      border = officer::fp_border(color = flex_x$body$styles$cells$border.color.top$data[1,1], width = 0.8)
     )
 
   return(flex_x)
